/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

'use strict';
/**
 * Write your transaction processor functions here
 */

/**
 * Create a good
 * @param {org.network.createGood} input
 * @transaction
*/
async function createGood(input){
    var factory = getFactory();
    let good = factory.newResource("org.network", "Good", input.id);
    good.name = input.name;
    good.description = input.description;
    good.owner = input.owner;
    good.history = [];

    let assetRegistry = await getAssetRegistry('org.network.Good');
    await assetRegistry.add(good);
}

/**
 * @param {org.network.moveGood} input
 * @transaction
*/
async function moveGood(input){
    const good = input.good;
    let assetRegistry = await getAssetRegistry('org.network.Good');
    good.owner = input.to;

    if(good.history == undefined){
        good.history = [];
    }

    //save the current date, time and a note in the record
    var factory = getFactory();
    const history = factory.newConcept('org.network','History');
    history.description = input.description;
    history.type = 'MOVED';
    history.time = new Date();
    history.doneBy = input.to;

    good.history.push(history);

    await assetRegistry.update(good);
}

/**
 * @param {org.network.changeGood} input
 * @transaction
*/
async function changeGood(input){
    const good = input.good;
    let assetRegistry = await getAssetRegistry('org.network.Good');
    if(good.history == undefined){
        good.history = [];
    }

    //save the current date, time and a note in the record
    var factory = getFactory();
    const history = factory.newConcept('org.network','History');
    history.description = input.description;
    history.type = 'MODIFIED'
    history.time = new Date();
    history.doneBy = input.to;

    good.history.push(history);

    await assetRegistry.update(good);
}


